==> benno-web-2.8.10.tgz: srv/benno/bennoweb/htdocs/ctrl/repeatQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

// repeat last query from session
$Query   = $QueryResult->Query;
$startNum = $QueryResult->first;

// number of messages may be changed in ui
if ($select_number = $App->getParam('select_number')) {
    $search_limit = $select_number;
    $App->setSession('search_limit',$search_limit);
    // new result list should be starting with first mail
    $startNum = 0;
}

// sort order may be changed in ui
if ($_sortOrder = $App->getParam('select_nachricht')) {
    // new result list should be starting with first mail
    $sortOrder = $_sortOrder;
    $startNum = 0;
    $App->setSession('sortOrder',$sortOrder);
}
$Query->setSortOrder($sortOrder);

try {
    $QueryResult = $Backend->query($archive,$Query,$startNum,$search_limit);
    $sessionMailId = $QueryResult->getSessionMailId(0);
}
catch (Exception $e) {
    $App->log('[searchSimple] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

$App->view = 'showList';

?>

==> benno-web-2.10.8.tgz: srv/benno/bennoweb/htdocs/ctrl/repeatQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

// repeat last query from session
$Query   = $QueryResult->Query;
$startNum = $QueryResult->first;

// number of messages may be changed in ui
if ($select_number = $App->getParam('select_number')) {
    $search_limit = $select_number;
    $App->setSession('search_limit',$search_limit);
    // new result list should be starting with first mail
    $startNum = 0;
}

// sort order may be changed in ui
if ($_sortOrder = $App->getParam('select_nachricht')) {
    // new result list should be starting with first mail
    $sortOrder = $_sortOrder;
    $startNum = 0;
    $App->setSession('sortOrder',$sortOrder);
}
$Query->setSortOrder($sortOrder);

try {
    $QueryResult = $Backend->query($archive,$Query,$startNum,$search_limit);
    $sessionMailId = $QueryResult->getSessionMailId(0);
}
catch (Exception $e) {
    $App->log('[searchSimple] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

$redirect_params['queryData'] = $Query->getUrlParameter();
$redirect_params['startNum']  = $startNum;
$App->redirect('searchQuery',$redirect_params);
?>
